@@ -100,11 +100,13 @@ Compare this with IO::Scalar.
 use Carp;
 use strict;
 use vars qw($VERSION @ISA);
+use IO::Handle;
 
 # The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.116 $, 10;
+$VERSION = substr q$Revision: 1.117 $, 10;
 
 # Inheritance:
+@ISA = qw(IO::Handle);
 require IO::WrapTie and push @ISA, 'IO::WrapTie::Slave' if ($] >= 5.004);
 
 
@@ -564,7 +566,7 @@ __END__
 
 =head1 VERSION
 
-$Id: ScalarArray.pm,v 1.116 2000/05/03 12:14:50 eryq Exp $
+$Id: ScalarArray.pm,v 1.117 2000/09/28 06:32:28 eryq Exp $
 
 
 =head1 AUTHOR
